@@ -111,7 +111,7 @@ function(x, y, weights, size, Wts, mask=rep(TRUE, length(wts)),
     flush.console()
   }
   if(length(decay) == 1) decay <- rep(decay, length(wts))
-  .C("VR_set_net",
+  .C(VR_set_net,
      as.integer(net$n),
      as.integer(net$nconn),
      as.integer(net$conn),
@@ -119,8 +119,7 @@ function(x, y, weights, size, Wts, mask=rep(TRUE, length(wts)),
      as.integer(nsunits),
      as.integer(entropy),
      as.integer(softmax),
-     as.integer(censored),
-     PACKAGE = "nnet"
+     as.integer(censored)
      )
   ntr <- dim(x)[1]
   nout <- dim(y)[2]
@@ -129,7 +128,7 @@ function(x, y, weights, size, Wts, mask=rep(TRUE, length(wts)),
     stop("invalid weights vector")
   Z <- as.double(cbind(x,y))
   storage.mode(weights) <- "double"
-  tmp <- .C("VR_dovm",
+  tmp <- .C(VR_dovm,
             as.integer(ntr), Z, weights,
 	    as.integer(length(wts)),
 	    wts=as.double(wts),
@@ -137,20 +136,19 @@ function(x, y, weights, size, Wts, mask=rep(TRUE, length(wts)),
 	    as.integer(maxit),
 	    as.logical(trace),
 	    as.integer(mask),
-            as.double(abstol), as.double(reltol),
-            PACKAGE = "nnet"
+            as.double(abstol), as.double(reltol)
 	    )
   net$value <- tmp$val
   net$wts <- tmp$wts
-  tmp <- matrix(.C("VR_nntest",
+  tmp <- matrix(.C(VR_nntest,
 		   as.integer(ntr), Z, tclass = double(ntr*nout),
-		   as.double(net$wts), PACKAGE = "nnet")$tclass,  ntr, nout)
+		   as.double(net$wts))$tclass,  ntr, nout)
   dimnames(tmp) <- list(rownames(x), colnames(y))
   net$fitted.values <- tmp
   tmp <- y - tmp
   dimnames(tmp) <- list(rownames(x), colnames(y))
   net$residuals <- tmp
-  .C("VR_unset_net", PACKAGE = "nnet")
+  .C(VR_unset_net)
   if(entropy) net$lev <- c("0","1")
   if(softmax) net$lev <- colnames(y)
   net$call <- match.call()
@@ -191,22 +189,20 @@ predict.nnet <- function(object, newdata, type=c("raw","class"), ...)
     }
     ntr <- nrow(x)
     nout <- object$n[3]
-    .C("VR_set_net",
+    .C(VR_set_net,
        as.integer(object$n), as.integer(object$nconn),
        as.integer(object$conn), rep(0.0, length(object$wts)),
        as.integer(object$nsunits), as.integer(0),
-       as.integer(object$softmax), as.integer(object$censored),
-       PACKAGE = "nnet")
+       as.integer(object$softmax), as.integer(object$censored))
     z <- matrix(NA, nrow(newdata), nout,
                 dimnames = list(rn, dimnames(object$fitted)[[2]]))
-    z[keep, ] <- matrix(.C("VR_nntest",
+    z[keep, ] <- matrix(.C(VR_nntest,
                            as.integer(ntr),
                            as.double(x),
                            tclass = double(ntr*nout),
-                           as.double(object$wts),
-                           PACKAGE = "nnet"
+                           as.double(object$wts)
                            )$tclass, ntr, nout)
-    .C("VR_unset_net", PACKAGE = "nnet")
+    .C(VR_unset_net)
   }
   switch(type, raw = z,
 	 class = {
@@ -218,9 +214,8 @@ predict.nnet <- function(object, newdata, type=c("raw","class"), ...)
 
 eval.nn <- function(wts)
 {
-  z <- .C("VR_dfunc",
-	 as.double(wts), df = double(length(wts)), fp = as.double(1),
-          PACKAGE = "nnet")
+  z <- .C(VR_dfunc,
+	 as.double(wts), df = double(length(wts)), fp = as.double(1))
   fp <- z$fp
   attr(fp, "gradient") <- z$df
   fp
@@ -268,7 +263,7 @@ nnetHess <- function(net, x, y, weights)
   nw <- length(net$wts)
   decay <- net$decay
   if(length(decay) == 1) decay <- rep(decay, nw)
-  .C("VR_set_net",
+  .C(VR_set_net,
      as.integer(net$n),
      as.integer(net$nconn),
      as.integer(net$conn),
@@ -276,8 +271,7 @@ nnetHess <- function(net, x, y, weights)
      as.integer(net$nsunits),
      as.integer(net$entropy),
      as.integer(net$softmax),
-     as.integer(net$censored),
-     PACKAGE = "nnet"
+     as.integer(net$censored)
      )
   ntr <- dim(x)[1]
   if(missing(weights)) weights <- rep(1, ntr)
@@ -285,10 +279,10 @@ nnetHess <- function(net, x, y, weights)
     stop("invalid weights vector")
   Z <- as.double(cbind(x,y))
   storage.mode(weights) <- "double"
-  z <- matrix(.C("VR_nnHessian", as.integer(ntr), Z, weights,
-                 as.double(net$wts), H = double(nw*nw), PACKAGE = "nnet")$H,
+  z <- matrix(.C(VR_nnHessian, as.integer(ntr), Z, weights,
+                 as.double(net$wts), H = double(nw*nw))$H,
               nw, nw)
-  .C("VR_unset_net", PACKAGE = "nnet")
+  .C(VR_unset_net)
   z
 }
 
