@@ -1,12 +1,11 @@
 /*
  *  spatial/init.c by W. N. Venables and B. D. Ripley.  Copyright (C) 2002
  */
-#include <S.h>
-#include "verS.h"
+#include <R.h>
 #include "spatial.h"
 #include "R_ext/Rdynload.h"
 
-R_CMethodDef CEntries[] = {
+static const R_CMethodDef CEntries[] = {
     {"VR_alset", (DL_FUNC) &VR_alset, 2},
     {"VR_correlogram", (DL_FUNC) &VR_correlogram, 8},
     {"VR_fmat", (DL_FUNC) &VR_fmat, 5},
